<?php

namespace Jiwei\EasyHttpSdk\Exception;

use GuzzleHttp\Exception\ConnectException;
use Jiwei\EasyHttpSdk\Helper\QueryPath;
use Jiwei\EasyHttpSdk\Http\SdkRequest;
use Throwable;

class ApplicationException extends ConnectException implements SdkExceptionInterface
{
    use QueryPath;

    /**
     * 额外信息
     * @var array<string, mixed>
     */
    private array $additionalData = [];

    /**
     * 应用异常
     *
     * @param string $message
     * @param SdkRequest|null $request
     * @param array<string, mixed> $handlerContext
     * @param Throwable|null $previous
     * @param array<string, mixed> $additionalData
     */
    public function __construct(
        string      $message,
        SdkRequest  $request = null,
        array       $handlerContext = [],
        ?Throwable $previous = null,
        array       $additionalData = []
    ) {
        $this->endpoint = is_null($request) ? "" : $request->getEndpoint();
        $this->action = is_null($request) ? "" : $request->getAction();
        $this->additionalData = $additionalData;
        parent::__construct($message, $request, $previous, $handlerContext);
    }

    /**
     * 获取额外的数据
     *
     * @return array<string, mixed>
     */
    public function getAdditionalData(): array
    {
        return $this->additionalData;
    }
}
